==> touhoulittlemaid-fabric-1.20.1-0.1.7-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityGarageKit.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import javax.annotation.Nullable;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;

public class TileEntityGarageKit extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityGarageKit> TYPE = class_2591.class_2592.method_20528(TileEntityGarageKit::new, InitBlocks.GARAGE_KIT).method_11034(null);
    private static final String FACING_TAG = "GarageKitFacing";
    private static final String EXTRA_DATA = "ExtraData";
    private class_2350 facing = class_2350.field_11043;
    private class_2487 extraData = new class_2487();

    public TileEntityGarageKit(class_2338 blockPos, class_2680 blockState) {
        super(TYPE, blockPos, blockState);
    }

    @Override
    public void method_11007(class_2487 pTag) {
        getPersistentData().method_10582(FACING_TAG, facing.method_15434());
        getPersistentData().method_10566(EXTRA_DATA, extraData);
        super.method_11007(pTag);
    }

    @Override
    public void method_11014(class_2487 pTag) {
        super.method_11014(pTag);
        facing = class_2350.method_10168(getPersistentData().method_10558(FACING_TAG));
        extraData = getPersistentData().method_10562(EXTRA_DATA);
    }

    @Override
    public class_2487 method_16887() {
        return this.method_38244();
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public class_2350 getFacing() {
        return facing;
    }

    public class_2487 getExtraData() {
        return extraData;
    }

    public void setData(class_2350 facing, class_2487 extraData) {
        this.facing = facing;
        this.extraData = extraData;
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.1.7.2-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityGarageKit.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import javax.annotation.Nullable;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;

public class TileEntityGarageKit extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityGarageKit> TYPE = class_2591.class_2592.method_20528(TileEntityGarageKit::new, InitBlocks.GARAGE_KIT).method_11034(null);
    private static final String FACING_TAG = "GarageKitFacing";
    private static final String EXTRA_DATA = "ExtraData";
    private class_2350 facing = class_2350.field_11043;
    private class_2487 extraData = new class_2487();

    public TileEntityGarageKit(class_2338 blockPos, class_2680 blockState) {
        super(TYPE, blockPos, blockState);
    }

    @Override
    public void method_11007(class_2487 pTag) {
        tlm$getPersistentData().method_10582(FACING_TAG, facing.method_15434());
        tlm$getPersistentData().method_10566(EXTRA_DATA, extraData);
        super.method_11007(pTag);
    }

    @Override
    public void method_11014(class_2487 pTag) {
        super.method_11014(pTag);
        facing = class_2350.method_10168(tlm$getPersistentData().method_10558(FACING_TAG));
        extraData = tlm$getPersistentData().method_10562(EXTRA_DATA);
    }

    @Override
    public class_2487 method_16887() {
        return this.method_38244();
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public class_2350 getFacing() {
        return facing;
    }

    public class_2487 getExtraData() {
        return extraData;
    }

    public void setData(class_2350 facing, class_2487 extraData) {
        this.facing = facing;
        this.extraData = extraData;
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }
}
